@@ -4,7 +4,6 @@
 from __future__ import annotations
 
 import os
-import sysconfig
 from contextlib import contextmanager, nullcontext, suppress
 from functools import partial
 from pathlib import Path
@@ -375,10 +374,8 @@ def get_requires_for_build_wheel(
 
     if is_pure_python_build:
         c_ext_build_deps = []
-    elif sysconfig.get_config_var('Py_GIL_DISABLED'):
-        c_ext_build_deps = ['Cython ~= 3.1.0a1']
     else:
-        c_ext_build_deps = ['Cython >= 3.0.12']
+        c_ext_build_deps = ['Cython >= 3.1.1']
 
     return _setuptools_get_requires_for_build_wheel(
         config_settings=config_settings,
